==> startbootstrap-shop-item-4.2.3.tgz: package/README.md <==
# [Start Bootstrap - Shop Item](https://startbootstrap.com/template/shop-item/)

[Shop Item](https://startbootstrap.com/template/shop-item/) is a basic HTML store item template for [Bootstrap](https://getbootstrap.com/) created by [Start Bootstrap](https://startbootstrap.com/).

## Preview

[![Shop Item Preview](https://assets.startbootstrap.com/img/screenshots/templates/shop-item.png)](https://startbootstrap.github.io/startbootstrap-shop-item/)

**[View Live Preview](https://startbootstrap.github.io/startbootstrap-shop-item/)**

## Status

[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/StartBootstrap/startbootstrap-shop-item/master/LICENSE)
[![npm version](https://img.shields.io/npm/v/startbootstrap-shop-item.svg)](https://www.npmjs.com/package/startbootstrap-shop-item)
[![Build Status](https://travis-ci.org/StartBootstrap/startbootstrap-shop-item.svg?branch=master)](https://travis-ci.org/StartBootstrap/startbootstrap-shop-item)
[![dependencies Status](https://david-dm.org/StartBootstrap/startbootstrap-shop-item/status.svg)](https://david-dm.org/StartBootstrap/startbootstrap-shop-item)
[![devDependencies Status](https://david-dm.org/StartBootstrap/startbootstrap-shop-item/dev-status.svg)](https://david-dm.org/StartBootstrap/startbootstrap-shop-item?type=dev)

## Download and Installation

To begin using this template, choose one of the following options to get started:

* [Download the latest release on Start Bootstrap](https://startbootstrap.com/template/shop-item/)
* Install via npm: `npm i startbootstrap-shop-item`
* Clone the repo: `git clone https://github.com/StartBootstrap/startbootstrap-shop-item.git`
* [Fork, Clone, or Download on GitHub](https://github.com/StartBootstrap/startbootstrap-shop-item)

## Usage

### Basic Usage

After downloading, simply edit the HTML and CSS files included with the template in your favorite text editor to make changes. These are the only files you need to worry about, you can ignore everything else! To preview the changes you make to the code, you can open the `index.html` file in your web browser.

### Advanced Usage

After installation, run `npm install` and then run `npm start` which will open up a preview of the template in your default browser, watch for changes to core template files, and live reload the browser when changes are saved. You can view the `gulpfile.js` to see which tasks are included with the dev environment.

You must have npm and Gulp installed globally on your machine in order to use these features.

## Bugs and Issues

Have a bug or an issue with this template? [Open a new issue](https://github.com/StartBootstrap/startbootstrap-shop-item/issues) here on GitHub or leave a comment on the [template overview page at Start Bootstrap](https://startbootstrap.com/template/shop-item/).

## About

Start Bootstrap is an open source library of free Bootstrap templates and themes. All of the free templates and themes on Start Bootstrap are released under the MIT license, which means you can use them for any purpose, even for commercial projects.

* <https://startbootstrap.com>
* <https://twitter.com/SBootstrap>

Start Bootstrap was created by and is maintained by **[David Miller](https://davidmiller.io/)**.

* <https://davidmiller.io>
* <https://twitter.com/davidmillerhere>
* <https://github.com/davidtmiller>

Start Bootstrap is based on the [Bootstrap](https://getbootstrap.com/) framework created by [Mark Otto](https://twitter.com/mdo) and [Jacob Thorton](https://twitter.com/fat).

## Copyright and License

Copyright 2013-2020 Start Bootstrap LLC. Code released under the [MIT](https://github.com/StartBootstrap/startbootstrap-shop-item/blob/gh-pages/LICENSE) license.

==> startbootstrap-shop-item-5.0.0.tgz: package/README.md <==
# [Start Bootstrap - Shop Item](https://startbootstrap.com/template/shop-item/)

[Shop Item](https://startbootstrap.com/template/shop-item/) is a basic HTML store item template for [Bootstrap](https://getbootstrap.com/) created by [Start Bootstrap](https://startbootstrap.com/).

## Preview

[![Shop Item Preview](https://assets.startbootstrap.com/img/screenshots/templates/shop-item.png)](https://startbootstrap.github.io/startbootstrap-shop-item/)

**[View Live Preview](https://startbootstrap.github.io/startbootstrap-shop-item/)**

## Status

[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/StartBootstrap/startbootstrap-shop-item/master/LICENSE)
[![npm version](https://img.shields.io/npm/v/startbootstrap-shop-item.svg)](https://www.npmjs.com/package/startbootstrap-shop-item)
[![dependencies Status](https://david-dm.org/StartBootstrap/startbootstrap-shop-item/status.svg)](https://david-dm.org/StartBootstrap/startbootstrap-shop-item)
[![devDependencies Status](https://david-dm.org/StartBootstrap/startbootstrap-shop-item/dev-status.svg)](https://david-dm.org/StartBootstrap/startbootstrap-shop-item?type=dev)

## Download and Installation

To begin using this template, choose one of the following options to get started:

* [Download the latest release on Start Bootstrap](https://startbootstrap.com/template/shop-item/)
* Install via npm: `npm i startbootstrap-shop-item`
* Clone the repo: `git clone https://github.com/StartBootstrap/startbootstrap-shop-item.git`
* [Fork, Clone, or Download on GitHub](https://github.com/StartBootstrap/startbootstrap-shop-item)

## Usage

### Basic Usage

After downloading, simply edit the HTML and CSS files included with `dist` directory. These are the only files you need to worry about, you can ignore everything else! To preview the changes you make to the code, you can open the `index.html` file in your web browser.

### Advanced Usage

Clone the source files of the theme and navigate into the theme's root directory. Run `npm install` and then run `npm start` which will open up a preview of the template in your default browser, watch for changes to core template files, and live reload the browser when changes are saved. You can view the `package.json` file to see which scripts are included.

#### npm Scripts

* `npm run build` builds the project - this builds assets, HTML, JS, and CSS into `dist`
* `npm run build:assets` copies the files in the `src/assets/` directory into `dist`
* `npm run build:pug` compiles the Pug located in the `src/pug/` directory into `dist`
* `npm run build:scripts` brings the `src/js/scripts.js` file into `dist`
* `npm run build:scss` compiles the SCSS files located in the `src/scss/` directory into `dist`
* `npm run clean` deletes the `dist` directory to prepare for rebuilding the project
* `npm run start:debug` runs the project in debug mode
* `npm start` or `npm run start` runs the project, launches a live preview in your default browser, and watches for changes made to files in `src`

You must have npm installed in order to use this build environment.

## Bugs and Issues

Have a bug or an issue with this template? [Open a new issue](https://github.com/StartBootstrap/startbootstrap-shop-item/issues) here on GitHub or leave a comment on the [template overview page at Start Bootstrap](https://startbootstrap.com/template/shop-item/).

## About

Start Bootstrap is an open source library of free Bootstrap templates and themes. All of the free templates and themes on Start Bootstrap are released under the MIT license, which means you can use them for any purpose, even for commercial projects.

* <https://startbootstrap.com>
* <https://twitter.com/SBootstrap>

Start Bootstrap was created by and is maintained by **[David Miller](https://davidmiller.io/)**.

* <https://davidmiller.io>
* <https://twitter.com/davidmillerhere>
* <https://github.com/davidtmiller>

Start Bootstrap is based on the [Bootstrap](https://getbootstrap.com/) framework created by [Mark Otto](https://twitter.com/mdo) and [Jacob Thorton](https://twitter.com/fat).

## Copyright and License

Copyright 2013-2021 Start Bootstrap LLC. Code released under the [MIT](https://github.com/StartBootstrap/startbootstrap-shop-item/blob/master/LICENSE) license.
